@@ -1,7 +1,7 @@
 package PNI::Node::Tk::MainWindow;
 use strict;
 use warnings;
-our $VERSION = '0.1';
+our $VERSION = '0.11';
 use base 'PNI::Node';
 use Tk;
 
@@ -36,16 +36,5 @@ Thanks to Nick Ing-Simmons in Perl/Tk can co-exist multiple MainWindows, so
 it is possible to create more than one Tk::MainWindow PNI node,
 but normally just one should be enough.
 
-=head1 AUTHOR
-
-G. Casati , E<lt>fibo@cpan.orgE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2010 by G. Casati
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =cut
 
